@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -118,32 +118,37 @@ sub _process {
 
         for my $col (0 .. $#{ $data->[$row] }) {
             my $tag = (!$row and !($args->{headless} or $args->{matrix})) ? 'th' : 'td';
-            my ( $val, $attr ) = _expand_code_or_hash( $args->{$tag}, $data->[$row][$col] );
+            my ( $cdata, $attr ) = _expand_code_or_hash( $args->{$tag}, $data->[$row][$col] );
             $args->{$tag} = [ $args->{$tag} ] unless ref( $args->{$tag} ) eq 'ARRAY';
 
-            # -rowXcolX
-            if (exists $args->{"-row${row}col${col}"}) {
-                ( $val, $attr ) = _expand_code_or_hash( $args->{"-row${row}col${col}"}, $val );
-            }
-
             # -colX
             if (exists $args->{"-col$col"}) {
-                ( $val, $attr ) = _expand_code_or_hash( $args->{"-col$col"}, $val );
+                my $new_attr;
+                ( $cdata, $new_attr ) = _expand_code_or_hash( $args->{"-col$col"}, $cdata );
+                $attr = { %{ $attr || {} }, %{ $new_attr || {} } };
             }
 
             # -rowX (overides -colX)
             if (exists $args->{"-row$row"}) {
                 my $new_attr;
-                ( $val, $new_attr ) = _expand_code_or_hash( $args->{"-row$row"}, $val );
-                $attr = $new_attr if ref( $new_attr );
+                ( $cdata, $new_attr ) = _expand_code_or_hash( $args->{"-row$row"}, $cdata );
+                $attr = { %{ $attr || {} }, %{ $new_attr || {} } };
             }
-            # --empty
-            do{ no warnings; $val =~ s/^\s*$/$empty/g };
+
+            # -rowXcolX (overides -rowX)
+            if (exists $args->{"-row${row}col${col}"}) {
+                my $new_attr;
+                ( $cdata, $new_attr ) = _expand_code_or_hash( $args->{"-row${row}col${col}"}, $cdata );
+                $attr = { %{ $attr || {} }, %{ $new_attr || {} } };
+            }
+
+            # handle empty
+            do{ no warnings; $cdata =~ s/^\s*$/$empty/g };
 
             $data->[$row][$col] = { 
                 tag => $tag, 
-                (defined( $val ) ? (cdata => $val) : ()), 
-                (defined( $attr ) ? (attr => $attr) : ()),
+                (defined( $cdata ) ? (cdata => $cdata) : ()), 
+                (defined( $attr )  ? (attr => $attr)   : ()),
             };
         }
     }
@@ -280,17 +285,17 @@ sub _args {
 }
 
 sub _expand_code_or_hash {
-    my ( $thingy, $val ) = @_;
+    my ( $thingy, $cdata ) = @_;
     my $attr;
     $thingy = [ $thingy ] unless ref( $thingy ) eq 'ARRAY';
     for (@{ $thingy }) {
         if (ref($_) eq 'CODE') {
-            $val = $_->($val);
+            $cdata = $_->($cdata);
         } elsif (ref($_) eq 'HASH') {
             $attr = $_;
         }
     }
-    return ( $val, $attr );
+    return ( $cdata, $attr );
 }
 
 
@@ -356,6 +361,9 @@ Headers on top. Same as
 
   generate( theta => 0 )
 
+=for html
+<table><tr><th>header1</th><th>header2</th><th>header3</th></tr><tr><td>a1</td><td>a2</td><td>a3</td></tr><tr><td>b1</td><td>b2</td><td>b3</td></tr><tr><td>c1</td><td>c2</td><td>c3</td></tr><tr><td>d1</td><td>d2</td><td>d3</td></tr></table>
+
 =item * C<landscape( %params )>
 
 =item * C<west( %params )>
@@ -364,18 +372,27 @@ Headers on left. Same as
 
   generate( theta => -270 )
 
+=for html
+<table><tr><th>header1</th><td>a1</td><td>b1</td><td>c1</td><td>d1</td></tr><tr><th>header2</th><td>a2</td><td>b2</td><td>c2</td><td>d2</td></tr><tr><th>header3</th><td>a3</td><td>b3</td><td>c3</td><td>d3</td></tr></table>
+
 =item * C<south( %params )>
 
 Headers on bottom. Same as
 
   generate( theta => -180, pinhead => 1 )
 
+=for html
+<table><tr><td>a1</td><td>a2</td><td>a3</td></tr><tr><td>b1</td><td>b2</td><td>b3</td></tr><tr><td>c1</td><td>c2</td><td>c3</td></tr><tr><td>d1</td><td>d2</td><td>d3</td></tr><tr><th>header1</th><th>header2</th><th>header3</th></tr></table>
+
 =item * C<east( %params )>
 
 Headers on right. Same as
 
   generate( theta => 90, pinhead => 1 )
 
+=for html
+<table><tr><td>a1</td><td>b1</td><td>c1</td><td>d1</td><th>header1</th></tr><tr><td>a2</td><td>b2</td><td>c2</td><td>d2</td><th>header2</th></tr><tr><td>a3</td><td>b3</td><td>c3</td><td>d3</td><th>header3</th></tr></table>
+
 Note that C<tgroups> are not allowed for C<south()> because the table
 is inverted horizontally and not allowed for C<west()> and C<east()>
 because the table rows contain both headings and cells. You can override
@@ -417,6 +434,12 @@ All methods/procedures accept the same named parameters.
 You do not have to specify C<data>, any bare array references
 will be collected and assigned to C<data>.
 
+=head2 LITERAL PARAMETERS
+
+Literal parameters provides the means to modify the macro
+aspects of the table, such as indentation, encoding, data
+source and table orientation.
+
 =over 4
 
 =item * C<data>
@@ -436,7 +459,8 @@ are XLS, CSV, JSON, YAML and HTML (first table found).
 =item * C<fill>
 
 Can be supplied instead of C<data> to generate empty
-cells.
+cells, or in conjunction with C<data> to pad existing
+cells (currently only pads the right and bottom sides.)
 
   fill => '5x12'
 
@@ -478,18 +502,18 @@ to insert into to.
 
 =item * C<encodes>
 
-HTML Encode contents of td tags. Defaults to empty string
-which performs no encoding of entities. Pass a string like
-'<>&=' to perform encoding on any characters found. If the
-value is 'undef' then all unsafe characters will be
-encoded as HTML entites.
+HTML Encode contents of <tr> and/or <td> tags. Defaults to
+empty string which performs no encoding of entities. Pass
+a string like '<>&=' to perform encoding on any characters
+found.  If the value is C<undef> then all unsafe characters
+will be encoded as HTML entites. Uses L<HTML::Entities>.
 
   encodes => '<>"'
 
 =item * C<empty>
 
-Replace empty cells with this value. Defaults to &nbsp;
-Set value to undef to avoid any substitutions.
+Replace empty cells with this value. Defaults to C<&nbsp;>.
+Set value to C<undef> to avoid any substitutions.
 
   empty => '&#160;'
 
@@ -517,6 +541,7 @@ only td tags, no th tags.
 =item * C<headless: 0 or 1>
 
 Render the table with without the headings row at all. 
+The first row is still C<-row1>.
 
 =item * C<headings>
 
@@ -532,7 +557,20 @@ Or both:
 
   headings => [ sub { uc shift }, { class => "foo" } ]
 
-C<headings> is a natural alias for C<-row0>.
+C<headings> is a natural alias for C<-row0>. Be careful
+not to prepend a dash to C<headings> ... only dynamic
+parameters use leading dashes.
+
+=back
+
+=head2 DYNAMIC PARAMETERS
+
+Dynamic parameters provide a means to control the micro
+elements of the table, such as modifying headings by their
+name and rows and columns by their indices (X). They contain
+leading dashes to seperate them from Literal and Tag Parameters.
+
+=over 4
 
 =item * C<-rowX>
 
@@ -576,7 +614,46 @@ name in that column:
 =item * C<-rowXcolX>
 
 Apply this anonymous subroutine or hash ref of attributres
-to the cell at row X and column X.  (0 index based)
+to the cell at row X and column X. (0 index based)
+
+=back
+
+=head2 TAG PARAMETERS
+
+Tag parameters provide a means to control the attributes
+of the table's tags, and in the case of <td> and <tr> the
+contents via callback subroutines. Although similar in form,
+they are differentiated from Litertal Tags because they share
+the names of the actual tags.
+
+=over 4
+
+=item * C<table>
+
+=item * C<thead>
+
+=item * C<tfoot>
+
+=item * C<tbody>
+
+=item * C<tr>
+
+Hash ref. Apply these attributes to the specified tag.
+
+  table => { class => 'spreadsheet' }
+
+  tr => { style => { background => [qw( color1 color2 )]' } }
+
+=item * C<th>
+
+=item * C<td>
+
+<th> and <td> are the only Tag Parameters that may
+additionally accept sub refs.
+
+  th => sub { uc shift }
+
+  td => [ sub { uc shift }, { class => 'foo' } ]
 
 =item * C<caption>
 
@@ -601,32 +678,6 @@ Add colgroup tag(s) to the table. Use an AoH for multiple.
 Add col tag(s) to the table. Use an AoH for multiple. Wraps
 tags within a colgroup tag. Same usage as C<colgroup>.
 
-=item * C<table>
-
-=item * C<thead>
-
-=item * C<tfoot>
-
-=item * C<tbody>
-
-=item * C<tr>
-
-Hash ref. Apply these attributes to the specified tag.
-
-  table => { class => 'spreadsheet' }
-
-  tr => { style => { background => [qw( color1 color2 )]' } }
-
-=item * C<th>
-
-=item * C<td>
-
-<th> and <td> can additionally accept sub refs
-
-  th => sub { uc shift }
-
-  td => [ sub { uc shift }, { class => 'foo' } ]
-
 =back
 
 =head1 REQUIRES
@@ -636,7 +687,8 @@ Hash ref. Apply these attributes to the specified tag.
 =item * L<HTML::AutoTag>
 
 Used to generate HTML. Handles indentation and HTML entity encoding.
-Uses L<Tie::Hash::Attribute> to handle rotation of class attributes.
+Uses L<Tie::Hash::Attribute> to handle rotation of class attributes
+and L<HTML::Entities> for encoding of CDATA.
 
 =item * L<Math::Matrix>
 
