@@ -9,6 +9,9 @@ use Spreadsheet::HTML::Presets::Calculator;
 eval "use Color::Spectrum";
 our $NO_SPECTRUM = $@;
 
+eval "use JavaScript::Minifier";
+our $NO_MINIFY = $@;
+
 sub layout {
     my $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
     my @args = (
@@ -81,6 +84,8 @@ sub calculator {
         -row4col0   => { colspan => 2, %attrs },
         _layout     => 1,
         data        => $data,
+        theta       => 0,
+        flip        => 0,
         tgroups     => 0,
         headless    => 0,
         pinhead     => 0,
@@ -360,10 +365,24 @@ my $tmpl = '
 }
 
 sub _html_tmpl {
-    return <<'END_HTML';
+    my %args = @_;
+
+    $args{jquery} ||= 'https://ajax.googleapis.com/ajax/libs/jquery/2.1.1/jquery.min.js';
+
+    unless ($NO_MINIFY) {
+        $args{code} = JavaScript::Minifier::minify(
+            input      => $args{code},
+            copyright  => 'Copyright (C) 2015 Jeff Anderson',
+            stripDebug => 1,
+        );
+    }
+
+    my $tmpl = <<'END_HTML';
 <script src="%s"></script>
 <script type="text/javascript">%s</script>
 END_HTML
+
+    return sprintf $tmpl, $args{jquery}, $args{code};
 }
 
 =head1 NAME
