@@ -4,31 +4,23 @@ use warnings FATAL => 'all';
 
 use Spreadsheet::HTML::Presets;
 
-eval "use JavaScript::Minifier";
-our $NO_MINIFY = $@;
-
 sub _javascript {
     my %args = @_;
 
-    $args{jquery} ||= 'https://ajax.googleapis.com/ajax/libs/jquery/2.1.1/jquery.min.js';
-
-    my $javascript = sprintf _js_tmpl(),
+    my $js = sprintf _js_tmpl(),
         $args{_max_rows},
         $args{_max_cols},
         join( ',', map "'$_'", @{ $args{colors} } ),
     ;
 
-    unless ($NO_MINIFY) {
-        $javascript = JavaScript::Minifier::minify( input => $javascript );
-    }
-
-    return sprintf Spreadsheet::HTML::Presets::_html_tmpl(), $args{jquery}, $javascript;
+    return Spreadsheet::HTML::Presets::_html_tmpl( code => $js, %args );
 }
 
 sub _js_tmpl {
     return <<'END_JAVASCRIPT';
 
 /* Copyright (C) 2015 Jeff Anderson */
+/* install JavaScript::Minifier to minify this code */
 var MATRIX;
 var ROW = %s;
 var COL = %s;
